@@ -6,7 +6,9 @@ print STDERR "Processing sample 1-1\n";
 
 @data = ( 
     ["1st","2nd","3rd","4th","5th","6th","7th", "8th", "9th"],
-    [    1,    2,    5,    6,    3,  1.5,    1,     3,     4],
+    #[    1,    2,    5,    6,    3,  1.5,    1,     3,     4],
+    [    0,    0,    0,    0,    0,    0,    0,     0,     0],
+    [    0,    0,    0,    0,    0,    0,    0,     0,     0],
 );
 
 $my_graph = new GD::Graph::bars();
